summaryrefslogtreecommitdiffstats
path: root/khtml/ecma/kjs_proxy.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/ecma/kjs_proxy.cpp')
-rw-r--r--khtml/ecma/kjs_proxy.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/khtml/ecma/kjs_proxy.cpp b/khtml/ecma/kjs_proxy.cpp
index 0301ef141..ca26c5a0b 100644
--- a/khtml/ecma/kjs_proxy.cpp
+++ b/khtml/ecma/kjs_proxy.cpp
@@ -343,8 +343,8 @@ void KJSProxyImpl::applyUserAgent()
assert( m_script );
TQString host = m_frame->m_part->url().isLocalFile() ? "localhost" : m_frame->m_part->url().host();
TQString userAgent = KProtocolManager::userAgentForHost(host);
- if (userAgent.tqfind(TQString::tqfromLatin1("Microsoft")) >= 0 ||
- userAgent.tqfind(TQString::tqfromLatin1("MSIE")) >= 0)
+ if (userAgent.find(TQString::fromLatin1("Microsoft")) >= 0 ||
+ userAgent.find(TQString::fromLatin1("MSIE")) >= 0)
{
m_script->setCompatMode(Interpreter::IECompat);
#ifdef KJS_VERBOSE
@@ -352,10 +352,10 @@ void KJSProxyImpl::applyUserAgent()
#endif
}
else
- // If we tqfind "Mozilla" but not "(compatible, ...)" we are a real Netscape
- if (userAgent.tqfind(TQString::tqfromLatin1("Mozilla")) >= 0 &&
- userAgent.tqfind(TQString::tqfromLatin1("compatible")) == -1 &&
- userAgent.tqfind(TQString::tqfromLatin1("KHTML")) == -1)
+ // If we find "Mozilla" but not "(compatible, ...)" we are a real Netscape
+ if (userAgent.find(TQString::fromLatin1("Mozilla")) >= 0 &&
+ userAgent.find(TQString::fromLatin1("compatible")) == -1 &&
+ userAgent.find(TQString::fromLatin1("KHTML")) == -1)
{
m_script->setCompatMode(Interpreter::NetscapeCompat);
#ifdef KJS_VERBOSE